OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Záložky",
    "You bookmarked \"%s\"" : "Pridali ste záložku „%s“",
    "%1$s bookmarked \"%2$s\"" : "%1$s ako záložka „%2$s“",
    "Someone bookmarked \"%s\"" : "Niekto pridal záložku „%s“",
    "You deleted \"%s\"" : "Odstránili ste „%s“",
    "Someone deleted \"%s\"" : "Niekto odstránil „%s“",
    "You created folder \"%s\"" : "Vytvorili ste priečinok „%s“",
    "%1$s created folder \"%2$s\"" : "%1$s vytvoril priečinok „%2$s“",
    "Someone created folder \"%s\"" : "Niekto vytvoril priečinok „%s“",
    "You moved folder \"%s\"" : "Premiestnili preičinok „%s“",
    "%1$s moved folder \"%2$s\"" : "%1$s premiestnil priečinok „%2$s“",
    "Someone moved folder \"%s\"" : "Niekto premiestnil priečinok „%s“",
    "You deleted folder \"%s\"" : "Odstránili ste priečinok „%s“",
    "%1$s deleted folder \"%2$s\"" : "%1$s odstránil priečinok „%2$s“",
    "Someone deleted folder \"%s\"" : "Niekto odstránil priečinok „%s“",
    "You shared folder \"%1$s\" with %2$s" : "Zdieľali ste priečinok „%1$s“ s %2$s",
    "You shared folder \"%s\" with someone" : "Zdieľali ste s niekym priečinok „%s“",
    "%1$s shared folder \"%2$s\" with you" : "%1$s zdieľal s vami priečinok „%2$s“",
    "Someone shared folder \"%s\" with you" : "Niekto s vami zdieľal priečinok „%s“",
    "You unshared folder \"%1$s\" with %2$s" : "Zrušili ste zdieľanie priečinka „%1$s“ s %2$s",
    "You unshared folder \"%s\" with someone" : "S niekym ste zrušili zdieľanie priečinka „%s“",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s s vami zrušil zdieľanie priečinka „%2$s“",
    "Someone unshared folder \"%s\" with you" : "Niekto s vami zrušil zdieľanie priečinka „%s“",
    "No file provided for import" : "Nie je k dispozícii žiadny súbor na import",
    "Unsupported file type for import" : "Nepodporovaný typ súboru na import",
    "Bookmarks shared by %s" : "Záložky, ktoré zdieľa %s",
    "Recent Bookmarks" : "Aktuálne záložky",
    "Bookmark" : "Záložka",
    "Bookmark deleted" : "Záložka zmazaná",
    "Bookmark created" : "Záložka vytvorená",
    "Bookmark moved" : "Záložka presunutá",
    "Bookmark updated" : "Záložka auktualizovaná",
    "Create bookmark" : "Vytvoriť záložku",
    "A Bookmark manager for Nextcloud" : "Manažér záložiek pre Nextcloud",
    "Select bookmark" : "Vybrať záložku",
    "Details" : "Detaily",
    "Rename" : "Premenovať",
    "Move" : "Presunúť",
    "Delete" : "Zmazať",
    "Search" : "Hľadať",
    "Select one or more tags" : "Zvoliť jeden alebo viac štítkov",
    "New" : "Nový",
    "New bookmark" : "Nová záložka",
    "New folder" : "Nový priečinok",
    "Grid view" : "Zobrazenie mriežky",
    "List view" : "Zobraziť ako zoznam",
    "Move selection" : "Presun výberu",
    "Delete selection" : "Zmazanie výberu",
    "Open all selected" : "Otvoriť všetky vybraté",
    "Select all" : "Vybrať všetko",
    "Cancel selection" : "Zrušiť výber",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Vybraté {folders} priečinky a {bookmarks} záložky",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Vybraná %n záložka","Vybrané %n záložky","Vybrané %n záložky","Vybraných %n záložiek"],
    "_Selected %n folder_::_Selected %n folders_" : ["Vybratý %n priečinok","Vybraté %n priečinky","Vybraté %n priečinky","Vybratých %n priečinkov"],
    "Enter a link" : "Zadať link",
    "Select folder" : "Vybrať priečinok",
    "Enter folder title" : "Zadať názov priečinka",
    "Shared by {user}" : "Zdieľa {user}",
    "Root folder" : "Koreňový priečinok",
    "Submit" : "Odoslať",
    "Cancel" : "Zrušiť",
    "Deleting selection" : "Maže sa výber",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Presúva sa %n priečinok a niektoré záložky","Presúvajú sa %n priečinky a niektoré záložky","Presúvajú sa %n priečinky a niektoré záložky","Presúva sa %n priečinkov a niektoré záložky"],
    "_Moving %n folder_::_Moving %n folders_" : ["Presúva sa %n priečinok","Presúvajú sa %n priečinky","Presúvajú sa %n priečinky","Presúva sa %n priečinkov"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Presúva sa %n záložka","Presúvajú sa %n záložky","Presúvajú sa %n záložky","Presúva sa %n záložiek"],
    "All bookmarks" : "Všetky záložky",
    "Recent" : "Nedávne",
    "Archived" : "Archivované",
    "Untagged" : "Bez štítku",
    "{used} bookmarks of {available} available" : "{used} záložky z {available} dostupných",
    "No archived bookmarks" : "Žiadne archivované záložky",
    "No bookmarks here" : "Žiadne záložky",
    "Add a bookmark" : "Pridať záložku",
    "Import bookmarks" : "Importovať záložky",
    "Import" : "Import",
    "Export" : "Export",
    "Sorting" : "Triedenie",
    "Recently added" : "Nedávno pridané",
    "Alphabetically" : "Abecedne",
    "Most visited" : "Najnavštevovanejšie",
    "Last modified" : "Naposledy zmenené",
    "Custom order" : "Vlastné poradie",
    "Client apps" : "Aplikácie klienta",
    "Also check out the collection of client apps that integrate with this app: " : "Pozrite si sadu klientskych aplikácií, ktoré sa integrujú do tejto aplikácie:",
    "Bookmarklet" : "Záložky",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Potiahnite túto položku do záložiek prehliadača a kliknutím pridajte stránku do záložiek",
    "Add to {instanceName}" : "Pridať do {instanceName}",
    "Clear data" : "Vyčistiť dáta",
    "Delete all bookmarks" : "Vymazať všetky záložky",
    "Do you really want to delete all your bookmarks?" : "Naozaj chcete zmazať všetky svoje zložky?",
    "Title" : "Názov",
    "Link" : "Odkaz",
    "Creation date" : "Dátum vytvorenia",
    "Tags" : "Štítky",
    "Attachments" : "Prílohy",
    "Archived version" : "Archivovaná verzia",
    "Open archived file" : "Otvoriť archivovaný súbor",
    "Notes" : "Poznámky",
    "{time} ago" : "Pred {time} ",
    "Owner" : "Majiteľ",
    "Sharing" : "Sprístupnenie",
    "Select a user or group" : "Vybrať používateľa alebo skupinu",
    "Share link" : "Sprístupniť odkaz",
    "Copy link" : "Kopíruj odkaz",
    "Copy RSS feed" : "Kopírovať RSS kanál",
    "Delete link" : "Zmazať odkaz",
    "Create public link" : "Vytvoriť verejný odkaz",
    "Allow editing" : "Povoliť úpravy",
    "Allow sharing" : "Povoliť zdieľanie",
    "Remove share" : "Odstrániť zdieľanie",
    "Link copied" : "Odkaz skopírovaný",
    "RSS feed copied" : "RSS kanál je skopírovaný",
    "Select" : "Označiť",
    "Previews" : "Náhľady",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Na zobrazenie skutočných snímok obrazovky vašich webových stránok označených záložkami môžu záložky používať služby tretích strán na generovanie ukážok.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Môžete sa bezplatne zaregistrovať na adrese screeenly.com alebo si nastaviť vlastný server.",
    "Screeenly API URL" : "Screenly API URL",
    "Screeenly API key" : "Screenly API kľúč",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL API služby Webshot",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Kľúč k API služby ScreenshotMachine",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the pageres cli on your server and bookmarks will find it." : "Stačí nainštalovať Pageres CLI na server a záložky si ho nájdu.",
    "Privacy" : "Súkromie",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Záložky sa pokúsia získať prístup k webovým stránkam, ktoré pridáte, aby sa o nich automaticky pridali informácie.",
    "Enable accessing and collecting information from the web pages you add" : "Povoľte prístup a zhromažďovanie informácií z pridaných webových stránok",
    "Performance" : "Výkon",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "V inštalácii s veľkým počtom používateľov môže byť užitočné obmedziť počet záložiek v jednom účte.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximálny povolený počet záložiek na účet. (0 bez limitu; predvolená hodnota bez limitu)",
    "Failed to load settings" : "Nepodarilo sa načítať nastavenia",
    "Failed to save settings" : "Nepodarilo sa uložiť nastavenia",
    "This URL is already bookmarked! Overwrite?" : "Táto webová adresa sa už v záložkách nachádza. Chcete ju prepísať?",
    "Enter bookmark title" : "Zadať názov záložky",
    "Enter bookmark URL" : "Zadajte URL záložky",
    "Folder" : "Priečinok",
    "Root Folder" : "Koreňový priečinok",
    "Save" : "Uložiť",
    "Failed to find existing bookmark" : "Nepodarilo sa nájsť existujúcu záložku",
    "Failed to create bookmark" : "Nepodarilo sa vytvoriť záložku",
    "Failed to save bookmark" : "Nepodarilo sa uložiť záložku",
    "Failed to move bookmark" : "Nepodarilo sa presunúť záložku",
    "Failed to delete bookmark" : "Nepodarilo sa zmazať záložky",
    "Failed to rename tag" : "Nepodarilo sa premenovať štítok",
    "Failed to load tags" : "Nepodarilo sa načítať štítky",
    "Failed to load folders" : "Nepodarilo sa načítať priečinky",
    "Failed to delete folder" : "Nepodarilo sa zmazať priečinok",
    "Failed to create folder" : "Nepodarilo sa vytvoriť priečinok",
    "Failed to fetch bookmarks." : "Nepodarilo sa načítať záložky",
    "Failed to change setting" : "Nepodarilo sa zmeniť nastavenia",
    "Failed to load setting {key}" : "Nepodarilo sa načítať nastavenie {key}",
    "Failed to update share {shareId}" : "Nepodarilo sa aktualizovať zdieľanie {shareId}",
    "Failed to delete share {shareId}" : "Nepodarilo sa zmazať zdieľanie {shareId}.",
    "Bookmarks feed" : "Kanál záložiek"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
